---
title: <span class="badge object-type-scalar"></span> Millilitre
---
# <span class="badge object-type-scalar"></span> Millilitre

Volume: millilitre (mL)

## Definition

```python
# Volume: millilitre (mL)
Millilitre: typing.Literal["mlitre"] = "mlitre"
```
